@@ -41,7 +41,10 @@ class ProjectReaderBase:
 
     @property
     def zenlytic_project(self):
-        return self.read_yaml_if_exists(os.path.join(self.repo.folder, "zenlytic_project.yml"))
+        zenlytic_project = self.read_yaml_if_exists(os.path.join(self.repo.folder, "zenlytic_project.yml"))
+        if zenlytic_project:
+            return zenlytic_project
+        return self.read_yaml_if_exists(os.path.join(self.dbt_folder, "zenlytic_project.yml"))
 
     @property
     def dbt_project(self):
