@@ -9,7 +9,7 @@ class dbtProjectReader(ProjectReaderBase):
     def load(self) -> None:
         self.project_name = self.dbt_project["name"]
 
-        self.generate_manifest_json(self.repo.folder, self.profiles_dir)
+        self.generate_manifest_json(self.dbt_folder, self.profiles_dir)
         self.manifest = self.load_manifest_json()
 
         dbt_profile_name = self.dbt_project.get("profile", self.project_name)
@@ -105,7 +105,7 @@ class dbtProjectReader(ProjectReaderBase):
             "version": 1,
             "type": "view",
             "name": view["name"],
-            "model_name": self.profile_name,
+            "model_name": self.project_name,
             "description": view.get("description"),
             "row_label": meta.get("row_label"),
             "sql_table_name": f"ref('{view['name']}')",
@@ -133,16 +133,20 @@ class dbtProjectReader(ProjectReaderBase):
 
     @staticmethod
     def _make_dbt_dimension(dimension: dict):
-        return {
+        core = {
             "field_type": "dimension",
             "name": dimension["name"],
             "type": "string",
-            "label": dimension.get("label"),
             "sql": "${TABLE}." + dimension["name"],
             "description": dimension.get("description"),
             "hidden": not dimension.get("is_dimension"),
             **dimension.get("meta", {}),
         }
+        if dimension.get("label"):
+            core["label"] = dimension.get("label")
+        if dimension.get("primary_key"):
+            core["primary_key"] = dimension.get("primary_key")
+        return core
 
     def _make_dbt_metric(self, metric: dict):
         metric_dict = {
